@@ -94,7 +94,7 @@ class WebinarComponentV2(base.BaseComponent):
         )
 
     def update_register(self, **kwargs):
-        util.require_keys(kwargs, ["id", "action", "registrants"])
+        util.require_keys(kwargs, ["id"])
         return self.put_request(
             "/webinars/{}/registrants/status".format(kwargs.get("id")), data=kwargs
         )
